# Gaussian

Usually, instrument response function is modeled as the normalized gaussian distribution.

\begin{equation*}
{IRF}(t) = \frac{1}{\sigma \sqrt{2\pi}}\exp\left(-\frac{t^2}{2\sigma^2}\right)
\end{equation*}

Full Width at Half Maximum (fwhm) is $2\sqrt{2\log 2} \sigma$. 
